@@ -1,29 +1,23 @@
 package Dancer2::Plugin::Cache::CHI;
-BEGIN {
-  $Dancer2::Plugin::Cache::CHI::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Dancer plugin to cache response content (and anything else)
-$Dancer2::Plugin::Cache::CHI::VERSION = '1.6.0';
+$Dancer2::Plugin::Cache::CHI::VERSION = '1.7.0';
 use strict;
 use warnings;
-no warnings qw/ uninitialized /;
-
 use Carp;
 use CHI;
 
-use Dancer2 0.140001;
+use Dancer2 0.162000;
 
 use Dancer2::Plugin;
 
-with 'Dancer2::Plugin';
-
 register_hook 'before_create_cache';
 
 
 my %cache;
 my $cache_page; # actually hold the ref to the args
 my $cache_page_key_generator = sub {
-    return $_[0]->request->{path_info};
+    return $_[0]->request->path;
 };
 
 on_plugin_import {
@@ -99,15 +93,17 @@ register check_page_cache => sub {
 
             my $req =  $dsl->request;
 
-            return if grep { 
+            no warnings 'uninitialized';
+
+            return if grep {
                 # eval is there to protect from a regression in Dancer 1.31
                 # where headers can be undef
                 eval { $req->header($_) eq 'no-cache' }
             } qw/ Cache-Control Pragma /;
         }
 
-        $context->response(
-            Dancer2::Core::Response->new(
+        $context->set_response(
+        	Dancer2::Core::Response->new(
                 is_halted => 1,
                 ref $cached eq 'HASH'
                 ?
@@ -119,7 +115,7 @@ register check_page_cache => sub {
                 :
                 ( content => $cached )
             )
-        );
+		);
     };
 
     $dsl->app->add_hook( Dancer2::Core::Hook->new(
@@ -177,7 +173,7 @@ Dancer2::Plugin::Cache::CHI - Dancer plugin to cache response content (and anyth
 
 =head1 VERSION
 
-version 1.6.0
+version 1.7.0
 
 =head1 SYNOPSIS
 
